Skip to main contentCrate ic_safe_upgrades
Source - ChunkedModule
- Holds the meta-information needed for a chunked WASM install.
- UpgradeError
- Errors returned by
upgrade_canister.
- UpgradeErrorReason
- UpgradeStage
- Describes the stage of the upgrade during which an error occurred
or after which we could not confirm status.
- WasmModule
- The WASM to be installed.
- upgrade_canister
- Safely upgrade a canister to a new version, without blocking the caller from
being upgraded itself.
- CanisterId
- Represents a canister’s principal ID on the IC.